@@ -84,7 +84,7 @@
 #define CALENDAREVENTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef CALENDAREVENTS_NO_DEPRECATED
-#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef CALENDAREVENTS_NO_DEPRECATED_WARNINGS
 #  define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE CALENDAREVENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define CALENDAREVENTS_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
